enums/client/client_sign_out_mode library
Enums
- ClientSignOutMode
-
ClientSignOutModerepresents the mode that is used to sign out a client, and has two values:signOutandsignOutWithSessionDestroy.
ClientSignOutMode represents the mode that is used to sign out a client, and has two values:
signOut and signOutWithSessionDestroy.