PromotionStatus enum

This is defining an enumeration called PromotionStatus with four possible values: none, active, assigned, and redeemed. Each value is associated with a string representation ('NONE', 'ACTIVE', 'ASSIGNED', and 'REDEEMED', respectively).

Inheritance
Available extensions

Values

none → const PromotionStatus
const PromotionStatus('NONE')
active → const PromotionStatus
const PromotionStatus('ACTIVE')
assigned → const PromotionStatus
const PromotionStatus('ASSIGNED')
redeemed → const PromotionStatus
const PromotionStatus('REDEEMED')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
promotionStatus String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promotionStatusAsString() String
This function returns the promotion status as a string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getPromotionStatusFromString(String string) PromotionStatus
The function returns a PromotionStatus enum value based on a given string input.

Constants

values → const List<PromotionStatus>
A constant List of the values in this enum, in order of their declaration.