VoucherCodeStatus enum
This is defining an enumeration type called VoucherCodeStatus with four possible values:
unassigned, assigned, redeemed, and canceled. Each value is associated with a string
representation ('UNASSIGNED', 'ASSIGNED', 'REDEEMED', and 'CANCELED', respectively).
Values
- unassigned → const VoucherCodeStatus
-
const VoucherCodeStatus('UNASSIGNED') - assigned → const VoucherCodeStatus
-
const VoucherCodeStatus('ASSIGNED') - redeemed → const VoucherCodeStatus
-
const VoucherCodeStatus('REDEEMED') - canceled → const VoucherCodeStatus
-
const VoucherCodeStatus('CANCELED')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voucherCodeStatus → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
voucherCodeStatusAsString(
) → String - This function returns the voucher code status as a string.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getVoucherCodeStatusFromString(
String string) → VoucherCodeStatus - The function converts a string to a corresponding VoucherCodeStatus enum value.
Constants
-
values
→ const List<
VoucherCodeStatus> - A constant List of the values in this enum, in order of their declaration.