RecommendationViewEvent class
The class RecommendationViewEvent is used to create an event with specific parameters for tracking recommendation views.
- Inheritance
-
- Object
- Event
- CustomEvent
- RecommendationEvent
- RecommendationViewEvent
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
↔ Map<
String, Object> -
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asMap(
) → Map -
The function returns a map with the values of type, label, action, and parameters.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setItems(
List items) → void - The function sets a list of items as a parameter in a recommendation view.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited