withApiKey method

SyneriseInitializer withApiKey(
  1. String apiKey
)

The function sets the API key and returns the SyneriseInitializer object.

Args: apiKey (String): The apiKey parameter is a string that represents the API key of the Synerise client. This key is used to authenticate and authorize the client's access to the Synerise platform.

Implementation

SyneriseInitializer withApiKey(String apiKey) {
  _apiKey = apiKey;
  return this;
}