ScreenViewAudienceInfo class

The ScreenViewAudienceInfo class represents information about the audience of a screen view, including segments, query, and target type.

Constructors

ScreenViewAudienceInfo.fromMap(Map map)
ScreenViewAudienceInfo.fromMap(Map map) is a constructor that takes a Map as input and creates a new instance of ScreenViewAudienceInfo based on the values in the Map.

Properties

hashCode int
The hash code for this object.
no setterinherited
query String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<String>?
final
targetType String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited