model/promotions/promotion_discount_step library
Classes
- PromotionDiscountStep
-
The
PromotionDiscountStepclass represents a step in a promotion that includes a discount value and a usage threshold.
PromotionDiscountStep class represents a step in a promotion that includes a discount value
and a usage threshold.