VoucherCodesData class
The VoucherCodesData class represents voucher codes data and includes a constructor that takes a
Map as an argument to create a new instance of the class.
Constructors
- VoucherCodesData({required String code, required VoucherCodeStatus status, required int clientId, String? clientUuid, required String poolUuid, DateTime? expireIn, DateTime? redeemAt, DateTime? assignedAt, required DateTime createdAt, required DateTime updatedAt})
- VoucherCodesData.fromMap(Map map)
-
VoucherCodesData.fromMap(Map map)is a constructor that takes aMapas an argument and creates a new instance ofVoucherCodesDatausing the values from theMap. Thethis()syntax is used to call the main constructor ofVoucherCodesDataand pass in the values extracted from theMap. The values are extracted from theMapusing the keyscode,status,clientId,clientUuid,poolUuid,expireIn,redeemAt,assignedAt,createdAt, andupdatedAt. Some of these values are formatted using theSyneriseUtils.formatIntToDateTime()method before being passed to the constructor.
Properties
- assignedAt ↔ DateTime?
-
getter/setter pair
- clientId ↔ int
-
getter/setter pair
- clientUuid ↔ String?
-
getter/setter pair
- code ↔ String
-
getter/setter pair
- createdAt ↔ DateTime
-
getter/setter pair
- expireIn ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- poolUuid ↔ String
-
getter/setter pair
- redeemAt ↔ DateTime?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ VoucherCodeStatus
-
getter/setter pair
- updatedAt ↔ DateTime
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited