ScreenViewAudienceInfo class
The ScreenViewAudienceInfo class represents information about the audience of a screen view, including segments, query, and target type.
Constructors
- ScreenViewAudienceInfo.fromMap(Map map)
-
ScreenViewAudienceInfo.fromMap(Map map)is a constructor that takes aMapas input and creates a new instance ofScreenViewAudienceInfobased on the values in theMap.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited