PromotionDiscountStep class
The PromotionDiscountStep class represents a step in a promotion that includes a discount value
and a usage threshold.
Constructors
- PromotionDiscountStep({required int discountValue, required int usageThreshold})
- PromotionDiscountStep.fromMap(Map map)
-
PromotionDiscountStep.fromMap(Map map)is a constructor that takes aMapas an argument and initializes a newPromotionDiscountStepobject with the values from the map.
Properties
- discountValue ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usageThreshold ↔ int
-
getter/setter pair
Methods
-
asMap(
) → Map - The function returns a map with the values of discountValue and usageThreshold.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited