AssignVoucherData class
The AssignVoucherData class represents data related to a voucher, including its code, expiration date, redemption date, and creation/update timestamps.
Constructors
- AssignVoucherData({required String code, DateTime? expireIn, DateTime? redeemAt, DateTime? assignedAt, required DateTime createdAt, required DateTime updatedAt})
- AssignVoucherData.fromMap(Map map)
-
AssignVoucherData.fromMap(Map map)is a named constructor that creates an instance of theAssignVoucherDataclass from aMapobject. It takes aMapobject as an argument and uses its values to initialize the properties of theAssignVoucherDataobject.
Properties
- assignedAt ↔ DateTime?
-
getter/setter pair
- code ↔ String
-
getter/setter pair
- createdAt ↔ DateTime
-
getter/setter pair
- expireIn ↔ DateTime?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- redeemAt ↔ DateTime?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt ↔ DateTime
-
getter/setter pair
Methods
-
asMap(
) → Map - This function returns a map containing various properties of an object, including timestamps.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited